==> bdext-0.1.24.tar.gz: bdext-0.1.24/bdeissct_dl/bdeissct_model.py <==
LA = 'la'
PSI = 'psi'
RHO = 'rho'
REMOVAL_RATE = 'removal rate'
TRANSMISSION_RATE = 'transmission rate'
SAMPLING_PROBABILITY = 'sampling probability'
INFECTIOUS_TIME = 'infectious time'
REPRODUCTIVE_NUMBER = 'R0'

F_E = 'f_E'
MU = 'mu'
INCUBATION_PERIOD = 'incubation period'

F_SS = 'f_SS'
X_SS = 'X_SS'
SS_TRANSMISSION_RATIO = 'superspreading transmission ratio'
SS_FRACTION = 'superspreading fraction'


X_C = 'X_C'
UPSILON = 'upsilon'
KAPPA = 'kappa'
PHI = 'phi'
NOTIFIED_SAMPLING_RATE = 'notified sampling rate'
REMOVAL_TIME_AFTER_NOTIFICATION = 'removal time after notification'
NOTIFICATION_PROBABILITY = 'notification probability'

RATE_PARAMETERS = (LA, PSI, PHI, MU, TRANSMISSION_RATE, REMOVAL_RATE, NOTIFIED_SAMPLING_RATE)
TIME_PARAMETERS = (INCUBATION_PERIOD, INFECTIOUS_TIME, REMOVAL_TIME_AFTER_NOTIFICATION)



DEFAULT_MIN_PROB = 1e-6
DEFAULT_MAX_PROB = 1
DEFAULT_MIN_RATE = 1e-3
DEFAULT_MAX_RATE = 1e3


BD = 'BD'
BDCT = 'BDCT'
BDCT1 = 'BDCT1'
BDCT2 = 'BDCT2'
BDCT2000 = 'BDCT2000'

BDEI = 'BDEI'
BDEICT = 'BDEICT'
BDEICT1 = 'BDEICT1'
BDEICT2 = 'BDEICT2'
BDEICT2000 = 'BDEICT2000'

BDSS = 'BDSS'
BDSSCT = 'BDSSCT'
BDSSCT1 = 'BDSSCT1'
BDSSCT2 = 'BDSSCT2'
BDSSCT2000 = 'BDSSCT2000'

BDEISS = 'BDEISS'
BDEISSCT = 'BDEISSCT'
BDEISSCT1 = 'BDEISSCT1'
BDEISSCT2 = 'BDEISSCT2'
BDEISSCT2000 = 'BDEISSCT2000'



MODEL_FINDER = 'MF'

MODELS = (BD, BDCT, \
          BDEI, BDEICT, \
          BDSS, BDSSCT, \
          BDEISS, BDEISSCT)

DATA_TYPES = ['tree']


# TARGET_COLUMNS_BDCT = (REPRODUCTIVE_NUMBER, INFECTIOUS_TIME, REMOVAL_TIME_AFTER_NOTIFICATION, UPSILON)
# TARGET_COLUMNS_BD = (REPRODUCTIVE_NUMBER, INFECTIOUS_TIME)
TARGET_CT_COLUMNS = (UPSILON, X_C, KAPPA)
TARGET_INCUBATION_COLUMNS = (F_E,)
TARGET_SS_COLUMNS = (F_SS, X_SS)
TARGET_COLUMNS_BD = (LA, PSI)
TARGET_COLUMNS_BDCT = TARGET_COLUMNS_BD + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDEI = TARGET_COLUMNS_BD + TARGET_INCUBATION_COLUMNS
TARGET_COLUMNS_BDEICT = TARGET_COLUMNS_BDEI + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDSS = TARGET_COLUMNS_BD + TARGET_SS_COLUMNS
TARGET_COLUMNS_BDSSCT = TARGET_COLUMNS_BDSS + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDEISS = TARGET_COLUMNS_BDEI + TARGET_SS_COLUMNS
TARGET_COLUMNS_BDEISSCT = TARGET_COLUMNS_BDEISS + TARGET_CT_COLUMNS
QUANTILES = (0.025, 0.5, 0.975)
# QUANTILES = (0.5, )

MODEL2TARGET_COLUMNS = {}
MODEL2TARGET_COLUMNS[BD] = TARGET_COLUMNS_BD
MODEL2TARGET_COLUMNS[BDEI] = TARGET_COLUMNS_BDEI
MODEL2TARGET_COLUMNS[BDSS] = TARGET_COLUMNS_BDSS
MODEL2TARGET_COLUMNS[BDEISS] = TARGET_COLUMNS_BDEISS
for model in (BDCT, BDCT1, BDCT2, BDCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDCT
for model in (BDEICT, BDEICT1, BDEICT2, BDEICT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDEICT
for model in (BDSSCT, BDSSCT1, BDSSCT2, BDSSCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDSSCT
for model in (BDEISSCT, BDEISSCT1, BDEISSCT2, BDEISSCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDEISSCT

==> bdext-0.1.29.tar.gz: bdext-0.1.29/bdeissct_dl/bdeissct_model.py <==
LA = 'la'
PSI = 'psi'
RHO = 'rho'
INFECTIOUS_TIME = 'd_I'
REPRODUCTIVE_NUMBER = 'R'

F_E = 'f_E'
MU = 'mu'
INCUBATION_PERIOD = 'd_E'

F_S = 'f_S'
X_S = 'X_S'


X_C = 'X_C'
UPSILON = 'upsilon'
KAPPA = 'kappa'
PHI = 'phi'
REMOVAL_TIME_AFTER_NOTIFICATION = 'd_C'

RATE_PARAMETERS = (LA, PSI, PHI, MU)
TIME_PARAMETERS = (INCUBATION_PERIOD, INFECTIOUS_TIME, REMOVAL_TIME_AFTER_NOTIFICATION)



DEFAULT_MIN_PROB = 1e-6
DEFAULT_MAX_PROB = 1
DEFAULT_MIN_RATE = 1e-3
DEFAULT_MAX_RATE = 1e3


BD = 'BD'
BDCT = 'BDCT'
BDCT1 = 'BDCT1'
BDCT2 = 'BDCT2'
BDCT2000 = 'BDCT2000'

BDEI = 'BDEI'
BDEICT = 'BDEICT'
BDEICT1 = 'BDEICT1'
BDEICT2 = 'BDEICT2'
BDEICT2000 = 'BDEICT2000'

BDSS = 'BDSS'
BDSSCT = 'BDSSCT'
BDSSCT1 = 'BDSSCT1'
BDSSCT2 = 'BDSSCT2'
BDSSCT2000 = 'BDSSCT2000'

BDEISS = 'BDEISS'
BDEISSCT = 'BDEISSCT'
BDEISSCT1 = 'BDEISSCT1'
BDEISSCT2 = 'BDEISSCT2'
BDEISSCT2000 = 'BDEISSCT2000'



MODEL_FINDER = 'MF'

MODELS = (BD, BDCT, \
          BDEI, BDEICT, \
          BDSS, BDSSCT, \
          BDEISS, BDEISSCT)

DATA_TYPES = ['tree']


# TARGET_COLUMNS_BDCT = (REPRODUCTIVE_NUMBER, INFECTIOUS_TIME, REMOVAL_TIME_AFTER_NOTIFICATION, UPSILON)
# TARGET_COLUMNS_BD = (REPRODUCTIVE_NUMBER, INFECTIOUS_TIME)
TARGET_CT_COLUMNS = (UPSILON, X_C, KAPPA)
TARGET_INCUBATION_COLUMNS = (F_E,)
TARGET_SS_COLUMNS = (F_S, X_S)
TARGET_COLUMNS_BD = (LA, PSI)
TARGET_COLUMNS_BDCT = TARGET_COLUMNS_BD + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDEI = TARGET_COLUMNS_BD + TARGET_INCUBATION_COLUMNS
TARGET_COLUMNS_BDEICT = TARGET_COLUMNS_BDEI + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDSS = TARGET_COLUMNS_BD + TARGET_SS_COLUMNS
TARGET_COLUMNS_BDSSCT = TARGET_COLUMNS_BDSS + TARGET_CT_COLUMNS
TARGET_COLUMNS_BDEISS = TARGET_COLUMNS_BDEI + TARGET_SS_COLUMNS
TARGET_COLUMNS_BDEISSCT = TARGET_COLUMNS_BDEISS + TARGET_CT_COLUMNS
QUANTILES = (0.025, 0.5, 0.975)
# QUANTILES = (0.5, )

MODEL2TARGET_COLUMNS = {}
MODEL2TARGET_COLUMNS[BD] = TARGET_COLUMNS_BD
MODEL2TARGET_COLUMNS[BDEI] = TARGET_COLUMNS_BDEI
MODEL2TARGET_COLUMNS[BDSS] = TARGET_COLUMNS_BDSS
MODEL2TARGET_COLUMNS[BDEISS] = TARGET_COLUMNS_BDEISS
for model in (BDCT, BDCT1, BDCT2, BDCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDCT
for model in (BDEICT, BDEICT1, BDEICT2, BDEICT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDEICT
for model in (BDSSCT, BDSSCT1, BDSSCT2, BDSSCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDSSCT
for model in (BDEISSCT, BDEISSCT1, BDEISSCT2, BDEISSCT2000):
    MODEL2TARGET_COLUMNS[model] = TARGET_COLUMNS_BDEISSCT
